@@ -5,13 +5,15 @@ use 5.008;
 use Getopt::Long ();
 use File::Spec::Functions qw( catfile );
 
-our $VERSION = "0.13";
+our $VERSION = "0.14";
 our $CONF;
 
 my $ROOT         = $ENV{PERLBREW_ROOT} || "$ENV{HOME}/perl5/perlbrew";
 my $CONF_FILE    = catfile( $ROOT, 'Conf.pm' );
 my $CURRENT_PERL = $ENV{PERLBREW_PERL};
 
+sub current_perl { $ENV{CURRENT_PERL} || '' }
+
 my @GETOPT_CONFIG = (
     'pass_through',
     'no_ignore_case',
@@ -74,10 +76,6 @@ sub run {
     $self->run_command($self->get_args);
 }
 
-sub get_current_perl {
-    return $CURRENT_PERL;
-}
-
 sub get_args {
     my ( $self ) = @_;
     return @{ $self->{args} };
@@ -91,7 +89,10 @@ sub run_command {
     }
     elsif(!$x) {
         $x = 'help';
-        @args = (0, ($self->{help} ? 2 : 0));
+        @args = (0, $self->{help} ? 2 : 0);
+    }
+    elsif($x eq 'help') {
+        @args = (0, 2);
     }
 
     my $s = $self->can("run_command_$x");
@@ -133,15 +134,18 @@ if [[ -f $HOME/.perlbrew/init ]]; then
     source $HOME/.perlbrew/init
 fi
 
-export PATH_WITHOUT_PERLBREW=$(perl -e 'print join ":", grep { index($_, $ENV{PERLBREW_ROOT}) } split/:/,$ENV{PATH};')
-export PATH=$PERLBREW_PATH:$PATH_WITHOUT_PERLBREW
+__perlbrew_set_path () {
+    export PATH_WITHOUT_PERLBREW=$(perl -e 'print join ":", grep { index($_, $ENV{PERLBREW_ROOT}) } split/:/,$ENV{PATH};')
+    export PATH=$PERLBREW_PATH:$PATH_WITHOUT_PERLBREW
+}
+__perlbrew_set_path
 
 perlbrew () {
     case $1 in
         (use)
             if [[ -x "$PERLBREW_ROOT/perls/$2/bin/perl" ]]; then
                 eval $(command perlbrew env $2)
-                export PATH=$PERLBREW_PATH:$PATH_WITHOUT_PERLBREW
+                __perlbrew_set_path
             else
                 echo "$2 is not installed";
             fi
@@ -156,7 +160,7 @@ perlbrew () {
                 echo '# DO NOT EDIT THIS FILE' > $HOME/.perlbrew/init
                 command perlbrew env $2 >> $HOME/.perlbrew/init
                 source $HOME/.perlbrew/init
-                export PATH=$PERLBREW_PATH:$PATH_WITHOUT_PERLBREW
+                __perlbrew_set_path
             else
                 echo "$2 is not installed";
             fi
@@ -173,7 +177,7 @@ perlbrew () {
             echo '# DO NOT EDIT THIS FILE' > $HOME/.perlbrew/init
             command perlbrew env >> $HOME/.perlbrew/init
             source $HOME/.perlbrew/init
-            export PATH=$PERLBREW_PATH:$PATH_WITHOUT_PERLBREW
+            __perlbrew_set_path
             ;;
 
         (*)
@@ -389,12 +393,6 @@ INSTALL
                 $self->run_command_symlink_executables($as);
             }
 
-            eval {
-                $self->run_command_install_cpanm($as)
-                    unless -e "$ROOT/bin/cpanm";
-                1;
-            } or warn "WARNING: cpanm installation failed: $@";
-
             print <<SUCCESS;
 Installed $dist as $as successfully. Run the following command to switch to it.
 
@@ -414,6 +412,16 @@ FAIL
     }
 }
 
+sub format_perl_version {
+    my $self    = shift;
+    my $version = shift;
+    return sprintf "%d.%d.%d",
+      substr( $version, 0, 1 ),
+      substr( $version, 2, 3 ),
+      substr( $version, 5 );
+
+}
+
 sub get_installed_perls {
     my $self    = shift;
     my $current = readlink("$ROOT/perls/current");
@@ -423,15 +431,18 @@ sub get_installed_perls {
     for (<$ROOT/perls/*>) {
         next if m/current/;
         my ($name) = $_ =~ m/\/([^\/]+$)/;
-        push @result, { name => $name, is_current => ($CURRENT_PERL && ($name eq $CURRENT_PERL)) };
+        push @result, { name => $name, is_current => (current_perl eq $name) };
     }
 
     my $current_perl_executable = readlink("$ROOT/bin/perl") || `which perl`;
     $current_perl_executable =~ s/\n$//;
 
+    my $current_perl_executable_version;
     for ( uniq grep { -f $_ && -x $_ } map { "$_/perl" } split(":", $ENV{PATH}) ) {
+        $current_perl_executable_version =
+          $self->format_perl_version(`$_ -e 'print \$]'`);
         push @result, {
-            name       => $_,
+            name => $_ . " (" . $current_perl_executable_version . ")",
             is_current => $current_perl_executable && ($_ eq $current_perl_executable)
         } unless index($_, $ROOT) == 0;
     }
@@ -729,6 +740,10 @@ your shell:
     chmod +x perlbrew
     ./perlbrew install
 
+or more simply:
+
+    curl -L http://xrl.us/perlbrewinstall | bash
+
 After that, C<perlbrew> installs itself to C<~/perl5/perlbrew/bin>,
 and you should follow the instruction on screen to setup your
 C<.bashrc> or C<.cshrc> to put it in your PATH.
@@ -797,15 +812,13 @@ Kang-min Liu  C<< <gugod@gugod.org> >>
 
 Copyright (c) 2010, Kang-min Liu C<< <gugod@gugod.org> >>.
 
-The standalone executable contains the following modules embedded.
-
 =head1 LICENCE
 
 The MIT License
 
 =head1 CONTRIBUTORS
 
-Patches and code improvements has been contributed by:
+Patches and code improvements have been contributed by:
 
 Tatsuhiko Miyagawa, Chris Prather, Yanick Champoux, aero, Jason May,
 Jesse Leuhrs, Andrew Rodland, Justin Davis, Masayoshi Sekimura,
